
; A 128X64 graphical LCD is connected to microcontroller.

;                                ______________________________    
;                               |                              |    +5
;                               |                        VDD  2|_____|
;              P1.0 ------------|7   DB0                       |    _|_
;              P1.1 ------------|8   DB1                       |   |   |       
;              P1.2 ------------|9   DB2                  VO  3|-->|   | 20K   
;              P1.3 ------------|10  DB3                       |   |   |       
;              P1.4 ------------|11  DB4     128X64 LCD        |   |_ _| Contrast
;              P1.5 ------------|12  DB5                       |     |         
;              P1.6 ------------|13  DB6                 VEE 18|_____| 
;              P1.7 ------------|14  DB7                       |        
;                               |                              |
;              P3.2 ------------|4   D/IBAR              GND  1|-- GND
;              P3.3 ------------|5   R/WBAR                    |           
;              P3.6 ------------|6   E                         |   
;              P3.1 ------------|15  CS1                 BL+ 19|-- +5
;              P3.4 ------------|16  CS2                       |   
;              P3.5 ------------|17  RSTBAR              BL- 20|-- GND
;                               |                              |
;                               |______________________________|                       

 

; Microcontrollers with 256B RAM can be used (89C52,89S52,89C55WD,...)

/////////////LCD CONTROLLER : NT7108   /////////////////

;-----------------------------------------------------------------------------

                INVERSE_F               BIT             00H
                CHAR_COUNTER            EQU             30H

;-----------------------------------------------------------------------------

; I/O PINS:

                LCD_DATA                EQU             P1
                
                DIBAR                  	BIT             P3.2//////RS 3.0
                RWBAR                	BIT             P3.3/////////3.1
                ENABLE                  BIT             P3.6/////////3.2
                CS1                     BIT             P3.1/////////3.3
                CS2                     BIT             P3.4/////////3.4
                RST_BAR                 BIT             P3.5/////////3.5                
                
;-----------------------------------------------------------------------------
                        
        		ORG     00H

START:		

				////Init/////////
				CLR RST_BAR
				LCALL DLY
				SETB RST_BAR
				LCALL DLY
				CLR ENABLE
				CLR CS1
				CLR CS2
				CLR DIBAR
				CLR RWBAR
				LCALL  LCDINIT
				
WRITE_LCD_LOOP:
////Just display some random dots on LCD/////////////////
				MOV A,#0B8H
				LCALL WRITE_CMD_CS1
				MOV A,#0B8H
				LCALL WRITE_CMD_CS2
				MOV A,#040H
				LCALL WRITE_CMD_CS1
				MOV A,#040H
				LCALL WRITE_CMD_CS2


				MOV DPTR, #GRAPHIC_GLX
				MOV R1,#40H			   
WC_LOOP:		CLR A
               	
				MOVC A,@A+DPTR
				LCALL WRITE_DATA_CS1          
				MOVC A,@A+DPTR
				LCALL WRITE_DATA_CS2               	

				INC DPTR
				DJNZ R1,WC_LOOP
				
				LCALL DLY3SEC
				
				///////Repeat the Displays///// 				
				LJMP WRITE_LCD_LOOP	

LCDINIT:

////////////////Init Sub////////////////////////////				
				MOV A,#03FH
				LCALL WRITE_CMD_CS1
			   	MOV A,#03FH
				LCALL WRITE_CMD_CS2

				MOV A,#0C0H
				LCALL WRITE_CMD_CS1
				MOV A,#0C0H
				LCALL WRITE_CMD_CS2
				RET

WRITE_CMD_CS1:		///A is the parameter
				
				SETB CS1
				CLR CS2
				CLR DIBAR
				CLR RWBAR
   				MOV LCD_DATA,A
				SETB ENABLE
				LCALL DLY
				CLR ENABLE
				LCALL LCDBUSY1
   				CLR CS1
  				CLR	CS2

				RET

WRITE_DATA_CS1:		///A is the parameter
				
				SETB CS1
				CLR CS2
				SETB DIBAR
				CLR RWBAR
   				MOV LCD_DATA,A
				SETB ENABLE
   				LCALL DLY
				CLR ENABLE
   				LCALL LCDBUSY1
				 
				CLR CS1
  				CLR	CS2
				RET

WRITE_CMD_CS2:		///A is the parameter
				
				SETB CS2
				CLR CS1
				CLR DIBAR
				CLR RWBAR
   				MOV LCD_DATA,A
				SETB ENABLE
				LCALL DLY
				CLR ENABLE
				LCALL LCDBUSY2
   				CLR CS1
  				CLR	CS2

				RET

WRITE_DATA_CS2:		///A is the parameter
				
				SETB CS2
				CLR CS1
				SETB DIBAR
				CLR RWBAR
   				MOV LCD_DATA,A
				SETB ENABLE
   				LCALL DLY
				CLR ENABLE
   				LCALL LCDBUSY2
				 
				CLR CS1
  				CLR	CS2
				RET


///////////////Check Busy Stat LCD CS1////////
LCDBUSY1:
				LCALL DLY
				ret
			  ///Check disabled temporarly////
				SETB RWBAR
				SETB CS1
  				CLR	CS2
				CLR DIBAR
				MOV LCD_DATA,#0FFH
LCDCHECK1LOOP:	SETB ENABLE 
   				LCALL DLY
				CLR ENABLE
				LCALL DLY
               	JB LCD_DATA.7,LCDCHECK1LOOP
               	
				RET

///////////////Check Busy Stat LCD CS2////////
LCDBUSY2:
				LCALL DLY
				ret
			  ///Check disabled temporarly////
				SETB RWBAR
				SETB CS2
  				CLR	CS1
				CLR DIBAR
				MOV LCD_DATA,#0FFH
LCDCHECK2LOOP:	SETB ENABLE 
   				LCALL DLY
				CLR ENABLE
				LCALL DLY
               	JB LCD_DATA.7,LCDCHECK2LOOP
               	
				RET
				
///////////////10 MS Loop////////////////////											
DLY:       		MOV R2,#00AH
DLYLOOP1:    	MOV R3,#00AH
DLYLOOP2:    	DJNZ R3,DLYLOOP2
               	DJNZ R2,DLYLOOP1
               	RET

///////////////Half Sec Loop/////////////////
DLYHALFSEC:    MOV R2,#0FFH
               MOV R3,#0FFH
HALFSECLP1:    DJNZ R3,HALFSECLP1
               DJNZ R2,HALFSECLP1
               
               MOV R2,#0FFH
               MOV R3,#0FFH
HALFSECLP2:    DJNZ R3,HALFSECLP2
               DJNZ R2,HALFSECLP2
 
               MOV R2,#0FFH
               MOV R3,#0FFH
HALFSECLP3:    DJNZ R3,HALFSECLP3
               DJNZ R2,HALFSECLP3
               RET

////////////////3 Sec Loop///////////////////
DLY3SEC:
				LCALL DLYHALFSEC
				LCALL DLYHALFSEC
				LCALL DLYHALFSEC
				LCALL DLYHALFSEC
				LCALL DLYHALFSEC
				LCALL DLYHALFSEC
				RET

///////////////Some Random Data For Display//////////////
GRAPHIC_GLX:
DB 040H,040H,040H,040H,040H,040H,0FFH,0FFH,040H,040H,040H,040H,040H,040H,0FFH,0FFH
DB 0FFH,0BCH,0BCH,002H,003H,0C1H,0F0H,0FCH,0FEH,00EH,004H,047H,04FH,04FH,047H,04FH
DB 06FH,02FH,0C7H,0F0H,0FFH,0FFH,005H,004H,0FCH,0FCH,00EH,006H,004H,0BCH,0BCH,0FFH
DB 0FFH,0FFH,042H,042H,042H,042H,042H,0FFH,0FFH,0FFH,042H,042H,042H,042H,042H,0FFH
DB 0FFH,0FFH,0BCH,0BCH,0BCH,040H,040H,040H,040H,040H,040H,040H,040H,040H,040H,040H
DB 0FCH,0FCH,0FEH,04AH,043H,041H,040H,040H,040H,060H,060H,060H,060H,040H,0BCH,0FFH
DB 0FFH,0BCH,020H,030H,01CH,00FH,003H,0ABH,0FFH,0FFH,0BCH,0ABH,003H,083H,0C0H,0F0H
DB 07EH,01FH,007H,0ABH,00FH,03EH,0F8H,0E0H,0C0H,080H,0BCH,0BCH,0BCH,0BCH,0FFH,0FFH
DB 0FFH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH
DB 0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH
DB 0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH
DB 0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH
DB 0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH
DB 0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH
DB 0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH
DB 0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0ABH,0FFH
DB 0FFH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0FFH
DB 0FFH,0BCH,0BCH,0BCH,0BCH,020H,020H,020H,0F0H,0F0H,010H,018H,018H,010H,0BCH,0BCH
DB 0BCH,0FCH,0FCH,0F8H,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0E0H,0E0H
DB 040H,040H,040H,040H,040H,040H,0C0H,0C0H,040H,040H,040H,040H,040H,040H,0E0H,0E0H
DB 0E0H,0BCH,0BCH,0BCH,0BCH,080H,0F0H,070H,030H,0BCH,040H,0C0H,0C0H,0F8H,0F8H,0F0H
DB 0C0H,0C0H,0C0H,0BCH,0BCH,0F8H,0F8H,030H,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0F8H,0F8H,0F0H,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,020H,020H,020H,020H,020H,020H,020H,020H,020H
DB 020H,020H,020H,020H,020H,0A0H,0E0H,0E0H,070H,070H,020H,0BCH,0BCH,0BCH,0BCH,0FFH
DB 0FFH,0BCH,0BCH,004H,004H,004H,0C4H,0F4H,0FFH,0FFH,0C4H,0C6H,086H,036H,03CH,03FH
DB 003H,0FFH,0FFH,0FFH,0F0H,01CH,00EH,007H,003H,0ABH,0BCH,0BCH,0BCH,0BCH,0FFH,0FFH
DB 040H,040H,040H,040H,040H,040H,0FFH,0FFH,040H,040H,040H,040H,040H,040H,0FFH,0FFH
DB 0FFH,0BCH,0BCH,002H,003H,0C1H,0F0H,0FCH,0FEH,00EH,004H,047H,04FH,04FH,047H,04FH
DB 06FH,02FH,0C7H,0F0H,0FFH,0FFH,005H,004H,0FCH,0FCH,00EH,006H,004H,0BCH,0BCH,0FFH
DB 0FFH,0FFH,042H,042H,042H,042H,042H,0FFH,0FFH,0FFH,042H,042H,042H,042H,042H,0FFH
DB 0FFH,0FFH,0BCH,0BCH,0BCH,040H,040H,040H,040H,040H,040H,040H,040H,040H,040H,040H
DB 0FCH,0FCH,0FEH,04AH,043H,041H,040H,040H,040H,060H,060H,060H,060H,040H,0BCH,0FFH
DB 0FFH,0BCH,020H,030H,01CH,00FH,003H,0ABH,0FFH,0FFH,0BCH,0ABH,003H,083H,0C0H,0F0H
DB 07EH,01FH,007H,0ABH,00FH,03EH,0F8H,0E0H,0C0H,080H,0BCH,0BCH,0BCH,0BCH,0FFH,0FFH
DB 080H,080H,080H,080H,080H,080H,0FFH,0FFH,080H,080H,080H,080H,080H,080H,0FFH,0FFH
DB 0FFH,0BCH,0BCH,002H,003H,0ABH,0BCH,0FFH,0FFH,0BCH,0BCH,0FFH,0FFH,01EH,002H,0FEH
DB 0FEH,0FEH,030H,010H,080H,0DFH,07FH,0FFH,0FFH,083H,0BCH,0BCH,0BCH,0BCH,0BCH,03FH
DB 03FH,01FH,008H,008H,008H,008H,008H,0FFH,0FFH,0FFH,008H,008H,008H,008H,008H,01FH
DB 01FH,00FH,0E0H,0E0H,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0FFH,0FFH,0FFH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0FFH
DB 0FFH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,003H,003H,006H,006H,003H,0ABH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0ABH,003H,003H,0ABH,0ABH,0BCH,0BCH,0ABH,0ABH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0ABH,0ABH
DB 0ABH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,007H,007H,002H,003H,0ABH,0BCH,008H,008H,00CH
DB 004H,006H,003H,003H,0ABH,0BCH,0BCH,0BCH,0ABH,003H,003H,002H,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,003H,007H,007H,004H,004H,004H,004H,004H,004H
DB 004H,004H,007H,007H,007H,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0ABH,003H,002H,006H,006H
DB 007H,007H,0ABH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0FFH
DB 0FFH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH
DB 0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0BCH,0FFH
DB 0FFH,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H
DB 080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H
DB 080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H
DB 080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H
DB 080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H
DB 080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H
DB 080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H
DB 080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,080H,0FFH

END

